class NumberProperties:
    
    def is_even(self, number):
        remainder = number % 2
        if remainder == 0:
            return True
        else:
            return False
    
    
    def is_odd(self, number):
        remainder = number % 2
        if remainder != 0:
            return True
        else:
            return False
            
            
    def is_multiple_of_n(self, number, n):
        remainder = number % n
        if remainder == 0:
            return True
        else:
            return False
    


if __name__ == '__main__':
    np = NumberProperties()
    number = 24
    n = 5
    print('\n{} is even?: {}'.format(number, np.is_even(number)))
    print('{} is odd?: {}'.format(number, np.is_odd(number)))
    property = np.is_multiple_of_n(number, n)
    print('{} is multiple of {}?: {}'.format(number, n, property))
    
    number = 25
    n = 5
    print('\n{} is even?: {}'.format(number, np.is_even(number)))
    print('{} is odd?: {}'.format(number, np.is_odd(number)))
    property = np.is_multiple_of_n(number, n)
    print('{} is multiple of {}?: {}'.format(number, n, property))
    
    number = 31
    n = 5
    print('\n{} is even?: {}'.format(number, np.is_even(number)))
    print('{} is odd?: {}'.format(number, np.is_odd(number)))
    property = np.is_multiple_of_n(number, n)
    print('{} is multiple of {}?: {}'.format(number, n, property))



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="smartnumber", # Replace with your own username
    version="0.0.1",
    author="",
    author_email="",
    description="A simple educational example.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="",
    packages=setuptools.find_packages(),
    install_requires=[''], # if you have libraries that your module depends on you would include them here
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)